<script setup>
import JetModal from '@/Jetstream/Modal.vue';
import Highcharts from 'highcharts';
import VueMultiselect from 'vue-multiselect';
import { Link } from '@inertiajs/inertia-vue3';
import DK_Input from '@/components/dk_Input.vue';
import Dk_Notification from '@/components/dk_Notification.vue';
import DK_Button from '@/components/dk_Button.vue';
import Datepicker from '@vuepic/vue-datepicker';
import '@vuepic/vue-datepicker/dist/main.css';
import { startOfDay, endOfDay, subDays, endOfMonth, endOfYear, startOfMonth, startOfYear, subMonths } from 'date-fns';
import { axiosApiCalls } from '../../../public/libs/datakorumJS';

let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}

</script>

<style>

table.dataTable thead th,
table.dataTable thead td {
    padding: 5px 10px;
    font-size: 0.9rem !important;
    border-bottom: 1px solid rgba(200, 200, 200, 0.75) !important;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:active {
    cursor: default;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 1px solid transparent;
    background: transparent;
    box-shadow: none;
}

.dataTables_wrapper .dataTables_paginate .paginate_button {
    box-sizing: border-box;
    display: inline-block;
    min-width: 1.5em;
    padding: 0.5em 1em;
    margin-left: 2px;
    text-align: center;
    text-decoration: none !important;
    cursor: pointer;
    cursor: manual;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 0;
    border-radius: 0.375rem;
}

.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
    color: rgba(200, 200, 200, 1) !important;
    background-color: rgba(0, 152, 219, 0.1) !important;
    background-image: unset !important;
    border: 0;
}

.dp__action_row {
    border-radius: 0.5rem;
}
.dp__input_reg {
    background: none;
    border-width: 1px;
    border-color: rgba(200, 200, 200, 0.9);
    border-radius: 0.5rem;
}
.dp__pointer {
    padding-top: 0.25rem;
    padding-bottom: 0.25rem;
}
.dp__theme_light {
    --dp-background-color: rgba(0, 57, 93, 0.95);
    --dp-text-color: #e3e3e3;
    --dp-hover-color: rgba(0, 255, 255, 0.2);
    --dp-hover-text-color: #FFFAFA;
    --dp-hover-icon-color: #e3e3e3;
    --dp-primary-color: rgba(0, 255, 255, 0.5);
    --dp-primary-text-color: #FFFAFA;
    --dp-secondary-color: #959595;
    --dp-border-color: #FFFAFA;
    --dp-menu-border-color: #FFFAFA;
    --dp-border-color-hover: #FFFAFA;
    --dp-disabled-color: #959595;
    --dp-scroll-bar-background: #f3f3f3;
    --dp-scroll-bar-color: #959595;
    --dp-success-color: rgba(5, 255, 243, 0.7);
    --dp-success-color-disabled: rgba(5, 255, 243, 0.7);
    --dp-icon-color: #e3e3e3;
    --dp-danger-color: #e6002e;
    --dp-highlight-color: rgba(25, 118, 210, 0.1);
}
</style>

<template>
    <AppLayout title="Dashboard">

        <Dk_Notification id="notification" :corner="false" :title="this.Notification_Title" :message="this.Notification_Message" :hover="this.Show_Notification"></Dk_Notification>

        <div style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background -z-1 overflow-y-scroll cursor-default">
            <div class="mx-6 mt-2 text-xs text-center text-gray-light font-light flex justify-between">
                <div class="grid place-content-center justify-start justify-items-start gap-2">
                    <div class="inline-flex justify-center items-center">
                        <p class="text-white-snow text-2xl w-full text-left">{{ this.data.device.name }}&nbsp;(Id:&nbsp;{{ this.data.device.id }})</p>
                    </div>
                    <Datepicker id="interval_date" class="min-w-[21rem]" v-model="date" vertical
                            :presetRanges="this.presetRanges" range @update:modelValue="methodUpdateDate" :clearable="false"
                            :format="this.methodFormatDatetoDatepicker"></Datepicker>
                </div>

                <div class="grid justify-items-stretch">
                    <div class="flex justify-start items-end">
                        <div class="flex gap-2">
                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.openParameters()">
                                {{ this.$t("general.Parameters") }}
                            </DK_Button>

                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityReadings', { idDevice: this.data.device.id })">
                                <DK_Button color="blue" :fixedSize="true">
                                    {{ this.$t("general.Readings") }}
                                </DK_Button>
                            </Link>

                            <DK_Button color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                {{ this.$t("general.Back") }}
                            </DK_Button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="px-6 py-4 w-full gap-4 grid 2xl:grid-cols-9 grid-cols-6">

                <!-- System -->
                <div class="baltoro-container-nr rounded-lg px-2 w-full pb-2 2xl:col-span-3 col-span-6">

                    <div class="flex flex-col gap-1 justify-start items-start w-full text-white-snow font-normal py-2">
                        <div class="flex flex-row justify-between items-start w-full">
                            <p class="text-2xl text-left text-cyan-text font-normal whitespace-nowrap pl-2"> {{ this.$t('general.System') }} </p>

                            <!-- Drivers System -->
                            <div class="flex flex-row justify-start items-center text-gray-medium/50 font-normal">
                                <div class="text-sm px-2 min-w-[2rem] text-center border border-gray-semimedium border-r-0 rounded-l-lg py-1" v-bind:class="{'font-medium text-white-snow bg-gradient-to-r from-gray-semimedium to-gray-medium' : this.data.data[1][0] == 0}">{{this.$t('general.Off')}}</div>
                                <div class="text-sm px-2 min-w-[2rem] text-center border border-gray-semimedium border-l-0 rounded-r-lg py-1" v-bind:class="{'font-medium text-white-snow bg-gradient-to-r from-success-start to-success-end' : this.data.data[1][0] == 1}">{{this.$t('general.On')}}</div>
                            </div>
                        </div>
                    </div>

                    <div class="w-full grid 2xl:grid-cols-6 grid-cols-12 gap-x-2 gap-y-1">

                        <div class="col-span-2 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(3)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 3}">
                            <!-- Current Value System -->
                            <div class="w-full" id='id_chart_0_3'></div>
                            <div class="w-full" id='id_label_0_3'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[3] }} </p>
                        </div>

                        <div class="col-span-2 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(4)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 4}">
                            <!-- Active Set Point Value System -->
                            <div class="w-full" id='id_chart_0_4'></div>
                            <div class="w-full" id='id_label_0_4'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[4] }} </p>
                        </div>

                        <div class="col-span-2 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(14)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 14}">
                            <!-- Set Point 1 System -->
                            <div class="w-full" id='id_chart_0_14'></div>
                            <div class="w-full" id='id_label_0_14'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[14] }} </p>
                        </div>

                        <div class="2xl:col-start-2 col-start-8 col-span-4 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 21}"> <!-- @click="this.setSensor(21)" -->
                            <!-- Error State System -->
                            <div class="w-full h-full flex justify-center items-center">
                                <div class="w-full h-fit grid grid-cols-8 gap-1 place-items-center text-gray-medium/50 font-normal">

                                    <div class="h-full w-full col-span-4 col-start-1 row-span-1 row-start-1 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-alert-start to-alert-end' : this.getBoolBit(this.data.data[21][0], 8)}"> {{this.$t('general.SensorError') }} </div>
                                    <div class="h-full w-full col-span-2 col-start-1 row-span-2 row-start-2 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-warning-start to-warning-end' : this.getBoolBit(this.data.data[21][0], 7)}"> P Max. </div>
                                    <div class="h-full w-full col-span-2 col-start-3 row-span-2 row-start-2 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-warning-start to-warning-end' : this.getBoolBit(this.data.data[21][0], 6)}"> P Min. </div>

                                    <div class="h-full w-full col-span-4 col-start-5 row-span-1 row-start-1 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-warning-start to-warning-end' : this.getBoolBit(this.data.data[21][0], 4)}">{{this.$t('general.DryRun') }}</div>
                                    <div class="h-full w-full col-span-1 col-start-5 row-span-2 row-start-2 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-alert-start to-alert-end' : this.getBoolBit(this.data.data[21][0], 3)}">{{this.$t('general.Pump') + ' 1 ' }}</div>
                                    <div class="h-full w-full col-span-1 col-start-6 row-span-2 row-start-2 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-alert-start to-alert-end' : this.getBoolBit(this.data.data[21][0], 2)}">{{this.$t('general.Pump') + ' 2 ' }}</div>
                                    <div class="h-full w-full col-span-1 col-start-7 row-span-2 row-start-2 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-alert-start to-alert-end' : this.getBoolBit(this.data.data[21][0], 1)}">{{this.$t('general.Pump') + ' 3 ' }}</div>
                                    <div class="h-full w-full col-span-1 col-start-8 row-span-2 row-start-2 text-sm border border-gray-low text-center rounded-lg py-0.5 grid place-items-center" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-alert-start to-alert-end' : this.getBoolBit(this.data.data[21][0], 0)}">{{this.$t('general.Pump') + ' 4 ' }}</div>
                                </div>
                            </div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[21] }} </p>
                        </div>

                    </div>
                </div>

                <!-- Pump 1 -->
                <div class="baltoro-container-nr rounded-lg px-2 w-full pb-2 col-span-3">

                    <div class="flex flex-col gap-1 justify-start items-start w-full text-white-snow font-normal py-2">
                        <div class="flex flex-row justify-between items-start w-full">
                            <p class="text-2xl text-left text-cyan-text font-normal whitespace-nowrap pl-2"> {{ this.$t('general.Pump') }} 1 </p>

                            <!-- Mode Pump 1 -->
                            <div class="flex flex-row gap-x-2 justify-start items-center text-gray-medium/50 font-normal">
                                <div class="text-sm px-2 min-w-[3rem] text-center rounded-lg py-1" v-bind:class="{'font-medium text-white-snow border-0 bg-gradient-to-r from-gray-semimedium to-gray-medium' : this.data.data[9][0] == 0}">{{this.$t('general.Off')}}</div>
                                <div class="text-sm px-2 min-w-[3rem] text-center rounded-lg py-1" v-bind:class="{'font-medium text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.data.data[9][0] == 1}">{{this.$t('general.Manual')}}</div>
                                <div class="text-sm px-2 min-w-[3rem] text-center rounded-lg py-1" v-bind:class="{'font-medium text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.data.data[9][0] == 2}">{{this.$t('general.Auto')}}</div>
                            </div>
                        </div>
                    </div>

                    <div class="w-full grid grid-cols-3 gap-x-2 gap-y-1">

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 6}">  <!-- @click="this.setSensor(6)" -->
                            <!-- State Pump 1 -->
                            <div class="w-full h-full flex justify-center items-center">
                                <div class="w-full h-fit grid grid-cols-2 gap-1 place-items-center text-gray-medium/50 font-normal">
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.getBoolBit(this.data.data[6][0], 6)}">{{this.$t('general.Auto')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.getBoolBit(this.data.data[6][0], 5)}">{{this.$t('general.Manual')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-gray-semimedium to-gray-medium' : this.getBoolBit(this.data.data[6][0], 4)}">{{this.$t('general.Disabled')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-success-start to-success-end' : this.getBoolBit(this.data.data[6][0], 3)}">{{this.$t('general.Run')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-alert-start to-alert-end' : this.getBoolBit(this.data.data[6][0], 1)}">{{this.$t('general.Error')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-warning-start to-warning-end' : this.getBoolBit(this.data.data[6][0], 0)}">{{this.$t('general.Reverse')}}</div>
                                </div>
                            </div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[6].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(12)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 12}">
                            <!-- Actual Speed Pump 1 -->
                            <div class="w-full" id='id_chart_1_12'></div>
                            <div class="w-full" id='id_label_1_12'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[12].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 19}"> <!-- @click="this.setSensor(19)" -->
                            <!-- Total Running Hours Pump 1 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_1_19'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[19].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(22)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 22}">
                            <!-- Input Power Pump 1 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_1_22'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[22].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(25)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 25}">
                            <!-- Consumption Pump 1 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_1_25'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[25].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(16)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 16}">
                            <!-- Switch Cycles Pump 1 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_1_16'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[16].slice(0, -7) }} </p>
                        </div>
                    </div>
                </div>

                <!-- Pump 2 -->
                <div class="baltoro-container-nr rounded-lg px-2 w-full pb-2 col-span-3">

                    <div class="flex flex-col gap-1 justify-start items-start w-full text-white-snow font-normal py-2">
                        <div class="flex flex-row justify-between items-start w-full">
                            <p class="text-2xl text-left text-cyan-text font-normal whitespace-nowrap pl-2"> {{ this.$t('general.Pump') }} 2 </p>

                            <!-- Mode Pump 2 -->
                            <div class="flex flex-row gap-x-2 justify-start items-center text-gray-medium/50 font-normal">
                                <div class="text-sm px-2 min-w-[3rem] text-center rounded-lg py-1" v-bind:class="{'font-medium text-white-snow border-0 bg-gradient-to-r from-gray-semimedium to-gray-medium' : this.data.data[10][0] == 0 }">{{this.$t('general.Off')}}</div>
                                <div class="text-sm px-2 min-w-[3rem] text-center rounded-lg py-1" v-bind:class="{'font-medium text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.data.data[10][0] == 1 }">{{this.$t('general.Manual')}}</div>
                                <div class="text-sm px-2 min-w-[3rem] text-center rounded-lg py-1" v-bind:class="{'font-medium text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.data.data[10][0] == 2 }">{{this.$t('general.Auto')}}</div>
                            </div>
                        </div>
                    </div>

                    <div class="w-full grid grid-cols-3 gap-x-2 gap-y-1">

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 7}"> <!-- @click="this.setSensor(7)" -->
                            <!-- State Pump 2 -->
                            <div class="w-full h-full flex justify-center items-center">
                                <div class="w-full h-fit grid grid-cols-2 gap-1 place-items-center text-gray-medium/50 font-normal">
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.getBoolBit(this.data.data[7][0], 6)}">{{this.$t('general.Auto')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-info-start to-info-end' : this.getBoolBit(this.data.data[7][0], 5)}">{{this.$t('general.Manual')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-gray-semimedium to-gray-medium' : this.getBoolBit(this.data.data[7][0], 4)}">{{this.$t('general.Disabled')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-success-start to-success-end' : this.getBoolBit(this.data.data[7][0], 3)}">{{this.$t('general.Run')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-alert-start to-alert-end' : this.getBoolBit(this.data.data[7][0], 1)}">{{this.$t('general.Error')}}</div>
                                    <div class="text-sm w-full border border-gray-low text-center rounded-lg py-0.5" v-bind:class="{'text-white-snow border-0 bg-gradient-to-r from-warning-start to-warning-end' : this.getBoolBit(this.data.data[7][0], 0)}">{{this.$t('general.Reverse')}}</div>
                                </div>
                            </div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[7].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(13)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 13}">
                            <!-- Actual Speed Pump 2 -->
                            <div class="w-full" id='id_chart_2_13'></div>
                            <div class="w-full" id='id_label_2_13'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap"> {{ this.data.names[13].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 20}"> <!-- @click="this.setSensor(20)" -->
                            <!-- Total Running Hours Pump 2 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_2_20'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[20].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(23)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 23}">
                            <!-- Input Power Pump 2 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_2_23'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[23].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(26)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 26}">
                            <!-- Consumption Pump 2 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_2_26'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[26].slice(0, -7) }} </p>
                        </div>

                        <div class="col-span-1 w-full flex flex-col justify-between items-center px-2 cursor-pointer h-[9.75rem] py-2 border border-transparent hover:border-gray-semimedium rounded-lg" @click="this.setSensor(17)"
                            v-bind:class="{'baltoro-container-nb-selected border-transparent hover:border-transparent' : this.selectedSensor == 17}">
                            <!-- Switch Cycles Pump 2 -->
                            <div class="w-full h-full flex justify-center items-center" id='id_label_2_17'></div>
                            <p class="text-xs text-center text-gray-light font-normal whitespace-nowrap pt-2"> {{ this.data.names[17].slice(0, -7) }} </p>
                        </div>
                    </div>
                </div>

                <!-- Graph -->
                <div class="baltoro-container-nr col-span-6 2xl:col-span-9 w-full rounded-lg p-2 row-span-1 flex flex-col justify-start items-start" v-bind:class="{'h-[15rem]' : typeof this.selectedSensor != 'undefined', 'h-0 hidden' : typeof this.selectedSensor == 'undefined'}">
                    <p v-if="this.selectedSensor != undefined" class="text-2xl text-left text-cyan-text font-normal whitespace-nowrap pl-2"> {{ this.data.names[this.selectedSensor] }} </p>
                    <div id='id_chart' class="w-full h-full"></div>
                </div>

            </div>
        </div>

        <JetModal :show="this.parametersModal" :closeable="false">

            <div class="p-6 cursor-default flex flex-col justify-between max-w-[40rem]"  v-bind:class="{'w-fit' : this.screen_width >= 768, 'w-[90vw]' : this.screen_width < 768}">

                <!--<p class="font-light text-center text-white-snow text-xl">{{ this.$t("general." + "Parameters") }}</p>-->

                <div class="w-full flex items-center justify-center flex-col">

                    <div class="flex flex-col justify-between items-start w-fit h-fit gap-4 col-span-3">
                        <div class="flex flex-col items-start justify-start gap-2 w-full">
                            <a class="font-normal text-left text-white-snow text-2xl whitespace-nowrap">{{this.$t('general.Actuators')}}</a>
                            <div class="w-full grid grid-cols-2 gap-6 place-items-center">
                                <div class="flex flex-col items-start gap-2 justify-between 2xl:w-[17.5rem] w-[15rem]">
                                    <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Relay status')}}</a>
                                    <VueMultiselect v-model="this.vmodel_idstatus" placeholder=""
                                            :options="this.options_idstatus" :close-on-select="true" :multiple="false"
                                            label="name" track-by="id" :allow-empty="false"/>
                                </div>
                                <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                    <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Parameter hiding')}}</a>
                                    <VueMultiselect v-model="this.vmodel_parameterhiding" placeholder=""
                                            :options="this.options_parameterhiding" :close-on-select="true" :multiple="false"
                                            label="name" track-by="id" :allow-empty="false"/>
                                </div>
                            </div>
                        </div>
                        <div class="flex justify-end gap-3 w-full">
                            <DK_Button color="blue" :fixedSize="true" id="idUpdate_1" v-on:click='this.updateParameters()' :off="this.timeout_command != undefined" :disabled="this.timeout_command != undefined">
                                {{ this.$t("general.Update") }}
                            </DK_Button>
                        </div>
                    </div>

                    <div class="my-4 w-full border-b border-gray-semimedium"></div>

                    <div class="flex flex-col justify-between items-start w-fit h-fit gap-4 col-span-3">
                        <div class="flex flex-col items-start justify-start gap-2 w-full">
                            <a class="font-normal text-left text-white-snow text-2xl whitespace-nowrap">{{this.$t('general.Registers')}}</a>
                            <div class="w-full grid grid-cols-2 gap-6 place-items-center">
                                <div class="flex flex-col items-start gap-2 justify-between 2xl:w-[17.5rem] w-[15rem]">
                                    <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{this.$t('general.Start function')}}</a>
                                    <VueMultiselect v-model="this.vmodel_idfunction" placeholder=""
                                            :options="this.options_idfunction" :close-on-select="true" :multiple="false"
                                            label="name" track-by="id" :allow-empty="false"/>
                                </div>
                                <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                    <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{ this.$t('general.Minimum frequency (Hz)') }}</a>
                                    <DK_Input id="id_fmin" type="text" :value="this.ini_fmin" :border="true" textPosition="center" width="full"/>
                                </div>
                                <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                    <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{ this.$t('general.Set point (%)') }}</a>
                                    <DK_Input id="id_point" type="text" :value="this.ini_point" :border="true" textPosition="center" width="full"/>
                                </div>
                                <div class="flex flex-col items-start gap-1 justify-between 2xl:w-[17.5rem] 2xl:px-0 w-full px-4">
                                    <a class="text-sm text-center text-cyan-text font-normal whitespace-nowrap">{{ this.$t('general.Integration time (s)') }}</a>
                                    <DK_Input id="id_integration" type="text" :value="this.ini_integration" :border="true" textPosition="center" width="full"/>
                                </div>
                            </div>
                        </div>
                        <div class="flex justify-end gap-3 w-full">
                            <DK_Button color="blue" :fixedSize="true" id="idUpdate_2" v-on:click='this.updateParameters()' :off="this.timeout_command != undefined" :disabled="this.timeout_command != undefined">
                                {{ this.$t("general.Update") }}
                            </DK_Button>
                        </div>
                    </div>

                    <div class="my-4 w-full border-b border-gray-semimedium"></div>

                </div>

                <div class="flex gap-2 font-light text-gray-light text-center justify-center w-full">

                    <DK_Button color="blue" :fixedSize="true" v-on:click="closeParameters()" >
                        {{ this.$t("general.Cancel") }}
                    </DK_Button>

                </div>
            </div>
        </JetModal>

    </AppLayout>
</template>

<script>
export default {
    props: ['data', 'user'],

    data() {
        return {
            Back: localStorage.getItem('Back'),
            screen_width: 0,
            date: undefined,
            parametersModal: false,

            Show_Notification: false,
            Notification_Title: '',
            Notification_Message: '',

            selectedSensor: undefined,

            formatDate: (date, utc) => {
                date = new Date(date);
                // utc en 0 para formatear hora local del usuario, 1 para formatear UTC
                if (utc == 0) { date.setHours(date.getHours() + this.user.timezone_offset) }
                else if (utc == -1) { date.setHours(date.getHours() - this.user.timezone_offset) }
                return (
                    date.getFullYear() + "-" +
                    ((date.getMonth() + 1 + '').length < 2 ? "0" + (date.getMonth() + 1) : (date.getMonth() + 1)) + "-" +
                    ((date.getDate() + '').length < 2 ? "0" + date.getDate() : date.getDate()) + " " +
                    ((date.getHours() + '').length < 2 ? "0" + date.getHours() : date.getHours()) + ":" +
                    ((date.getMinutes() + '').length < 2 ? "0" + date.getMinutes() : date.getMinutes()) + ":" +
                    ((date.getSeconds() + '').length < 2 ? "0" + date.getSeconds() : date.getSeconds())
                );
            },

            presetRanges: [
                { label: this.$t("general." + "Today"), range: [startOfDay(new Date()), new Date()] },
                { label: this.$t("general." + "Yesterday"), range: [startOfDay(subDays(new Date(), 1)), endOfDay(subDays(new Date(), 1))] },
                { label: this.$t("general." + "Last 7 Days"), range: [new Date().setDate(new Date().getDate() - 7), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "Last 14 Days"), range: [new Date().setDate(new Date().getDate() - 14), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "Last 30 Days"), range: [new Date().setDate(new Date().getDate() - 30), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "This month"), range: [startOfMonth(new Date()), new Date()] },
                { label: this.$t("general." + "Last month"), range: [startOfMonth(subMonths(new Date(), 1)), endOfMonth(subMonths(new Date(), 1))] }
            ],

            getElapsedTime: (tiempoEnHoras) => {
                var diferenciaEnMilisegundos = tiempoEnHoras * 60 * 60 * 1000;

                // Convertir la diferencia a días, horas, minutos y segundos
                const segundos = Math.floor(diferenciaEnMilisegundos / 1000);
                const minutos = Math.floor(segundos / 60);
                const horas = Math.floor(minutos / 60);
                const dias = Math.floor(horas / 24);

                // Crear un array para almacenar las partes no nulas del tiempo
                var parteDias = '';
                const partesTiempo = [];

                parteDias = `${dias}`;

                //disjoin = ' ';
                partesTiempo.push(`${horas % 24}`);
                partesTiempo.push(`${minutos % 60}`);
                partesTiempo.push(`${segundos % 60}`);

                // Unir las partes del tiempo en un string
                var tiempoFormateado = [ parteDias, partesTiempo];

                return tiempoFormateado;

            },

            timeout_command: undefined,

            //INITIAL
            ini_fmin: undefined,
            ini_point: undefined,
            ini_integration: undefined,


            //OPTIONS
            options_idstatus: undefined,
            options_idfunction: undefined,
            options_parameterhiding: undefined,


            //VMODELS
            vmodel_idstatus: undefined,
            vmodel_idfunction: undefined,
            vmodel_parameterhiding: undefined,
        }
    },

    beforeCreate() {
        this.$i18n.locale = this.user.language
    },

    beforeMount() {
        this.screen_width = window.screen.width;

        this.options_idstatus = [
            {
                id: 0,
                name: this.$t('general.OFF'),
            },{
                id: 1,
                name: this.$t('general.ON'),
            },
        ];
        this.options_idfunction = [
            {
                id: 0,
                name: this.$t('general.Ramp'),
            },{
                id: 1,
                name: this.$t('general.Start on the fly'),
            },
        ];
        this.options_parameterhiding = [
            {
                id: 0,
                name: this.$t('general.All visible'),
            },{
                id: 1,
                name: this.$t('general.Configuration group only'),
            },
        ];

        this.vmodel_idstatus = this.options_idstatus[0];
        this.vmodel_idfunction = this.options_idfunction[0];
        this.vmodel_parameterhiding = this.options_parameterhiding[0];

        this.ini_fmin = 5;
        this.ini_point = 87;
        this.ini_integration = 30;
    },

    mounted() {

        let formatDate = this.formatDate

        this.Chart = {
            chart: {
                zoomType: 'x',
                backgroundColor: 'transparent',
                spacingTop: 20,
                animation: {
                    duration: 150
                },
                resetZoomButton: {
                    position: {
                        align: 'left',
                        verticalAlign: 'top',
                        x: 0,
                        y: 2.5
                    },
                    theme: {
                        r: 5.6,
                    }
                }
            },
            accessibility: {
                enabled: false
            },
            title: {
                text: ''
            },
            xAxis: {
                lineColor: '#647F8C',
                visible: true,
                labels: {
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                type: "datetime",
                dateTimeLabelFormats: {
                    //millisecond: '%H:%M:%S.%L',
                    //second: '%H:%M:%S',
                    //minute: '%H:%M',
                    hour: '%H:%M',
                    day: '%m-%d',
                    week: '%m-%d',
                    month: '%Y-%m',
                    year: '%Y'
                },
                time: {
                    timezoneOffset: new Date().getTimezoneOffset(), // Configura la zona horaria actual
                    useUTC: false // Utiliza hora local
                }
            },
            yAxis: new Array(),
            exporting: {
                enabled: false
            },
            credits: {
                enabled: false
            },
            legend: {
                enabled: false,
                itemStyle: {
                    color: 'rgba(200, 200, 200, 0.9)',
                    opacity: 0.75,
                    fontWeight: 'light'
                },
                itemHoverStyle: {
                    color: 'rgba(200, 200, 200, 0.9)',
                    opacity: 1,
                    fontWeight: 'light'
                }
            },
            tooltip: {
                shared: true,
                split: false,
                backgroundColor: 'rgba(7,82,103,0.95)',
                borderRadius: 12,
                borderWidth: 1,
                borderColor: 'rgba(250, 250, 250, 0.65)',
                padding: 6,
                formatter: function () {
                    var s = '<b>' + '<p style="font-size:12px; line-height: 12px; font-weight: 300; color:rgba(250, 250, 250, 0.95)">' + formatDate(this.x, -1) + '</p><br/>';
                    $.each(this.points, function () {
                        s += '<p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.series.name + ': </p><p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.y +
                        ' ' + this.series.userOptions.tooltip.valueSuffix + '</p><br/>';
                    });

                    return s;
                },
            },
        };

        this.Gauge = {
            chart: {
                type: 'gauge',
                backgroundColor: "transparent",
                plotBackgroundColor: null,
                plotBackgroundImage: null,
                plotBorderWidth: 0,
                plotShadow: false,
                spacing: [0, 0, 0, 0], // Ajusta los márgenes del gráfico según tus necesidades
                height: 90,
                marginTop: -5,
                marginBottom: -35,
            },
            title: null,
            pane: {
                startAngle: -110,
                endAngle: 110,
                background: {
                backgroundColor: "transparent",
                borderWidth: 0
                }
            },
            tooltip: {
                enabled: false
            },
            xAxis: {
                title: {
                text: "",
                style: {
                    color: "#FFFAFA",
                    fontSize: "12px",
                    fontWeight: "normal",
                    fontStyle: "normal"
                }
                },
                labels: {
                    rotation: -45,
                    style: {
                        color: 'white',
                        fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                    }
                }
            },
            plotOptions: {
                gauge: {
                    borderWidth: 0,
                    borderColor: "#05fff3", // Cambia el color del borde de la serie a #05fff3
                    dataLabels: {
                        enabled: false, // Desactiva las etiquetas con el dato y su unidad
                    },
                    pivot: {
                        radius: "4%",
                        backgroundColor: "#fff", // Cambia el color del pivote a blanco
                    },
                    dial: {
                        backgroundColor: "#fff", // Cambia el color de la flecha a blanco
                        radius: "70%", // Ajusta el tamaño de la flecha según tus necesidades
                        baseWidth: 3, // Ajusta el ancho de la base de la flecha según tus necesidades
                        topWidth: 1, // Ajusta el ancho de la punta de la flecha según tus necesidades
                        baseLength: "10%", // Ajusta la longitud de la base de la flecha según tus necesidades
                        rearLength: "-20%", // Ajusta la longitud de la punta de la flecha según tus necesidades
                    }
                },
            },
            credits: {
                enabled: false
            },
            exporting: {
                enabled: false,
            }
        };

        let export_title = this.data.device.name + '_' + this.data.device.id + '_' + this.data.dates[0]

        this.table = $('#basicTable').DataTable({
            language: {
                url: '/assets/i18n/' + this.user.language + '.json'
            },
            order: [[0, "desc"]],
            dom: '<"row"<"col-sm-6"B><"col-sm-6">>t<"row"<"col-sm-6"i><"col-sm-6"p>><"clear">',
            ordering: true,
            pageLength: 10,
            buttons: [
                {
                    extend: 'csv',
                    text: 'CSV',
                    title: export_title,
                    className: 'btn btn-brand',
                    exportOptions: {
                        columns: ':visible'
                    }
                },
                {
                    extend: 'excel',
                    text: 'Excel',
                    title: export_title,
                    className: 'btn btn-brand',
                    exportOptions: {
                        columns: ':visible'
                    }
                },
                {
                    extend: 'print',
                    text: 'Print',
                    title: export_title,
                    className: 'btn btn-brand',
                    exportOptions: {
                        columns: ':visible'
                    }
                },
            ]
        });

        this.date = [
            new Date(this.formatDate(this.data.dates[this.data.dates.length - 1], 1)),
            new Date(this.formatDate(this.data.dates[0], 1))
        ];

        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        this.rechargePage();

    },

    methods: {

        rechargePage() {

            require('highcharts/highcharts-more')(Highcharts);

            for (let sensor in this.data.names) {

                let idComponent;

                switch(parseInt(sensor)){
                    //case 1:
                    //    idComponent = ['id_label_0_1'] // BOOL
                    //    break;

                    case 3:
                        idComponent = ['id_chart_0_3', 'id_label_0_3'] // GAUGE
                        break;

                    case 4:
                        idComponent = ['id_chart_0_4', 'id_label_0_4'] // GAUGE
                        break;

                    //case 6:
                    //    idComponent = ['id_label_1_6'] // WORD_BIT
                    //    break;
                    //
                    //case 7:
                    //    idComponent = ['id_label_2_7'] // WORD_BIT
                    //    break;
                    //
                    //case 9:
                    //    idComponent = ['id_label_1_9'] // WORD
                    //    break;
                    //
                    //case 10:
                    //    idComponent = ['id_label_2_10'] // WORD
                    //    break;

                    case 12:
                        idComponent = ['id_chart_1_12', 'id_label_1_12'] // GAUGE
                        break;

                    case 13:
                        idComponent = ['id_chart_2_13', 'id_label_2_13'] // GAUGE
                        break;

                    case 14:
                        idComponent = ['id_chart_0_14', 'id_label_0_14'] // GAUGE
                        break;

                    case 16:
                        idComponent = ['id_label_1_16'] // BLOCK
                        break;

                    case 17:
                        idComponent = ['id_label_2_17'] // BLOCK
                        break;

                    case 19:
                        idComponent = ['id_label_1_19'] // TIME
                        break;

                    case 20:
                        idComponent = ['id_label_2_20'] // TIME
                        break;

                    //case 21:
                    //    idComponent = ['id_label_0_21'] // WORD_BIT
                    //    break;

                    case 22:
                        idComponent = ['id_label_1_22'] // BLOCK
                        break;

                    case 23:
                        idComponent = ['id_label_2_23'] // BLOCK
                        break;

                    case 25:
                        idComponent = ['id_label_1_25'] // BLOCK
                        break;

                    case 26:
                        idComponent = ['id_label_2_26'] // BLOCK
                        break;
                }

                if(Array.isArray(idComponent)){

                    if (sensor == 3 || sensor == 4 || sensor == 12 || sensor == 13 || sensor == 14) { // Gauge
                        let min;
                        let max;

                        switch(parseInt(sensor)){
                            default:
                                min = 0;
                                max = 100;
                        }

                        this.Gauge.yAxis= {
                            min: min,
                            max: max,
                            tickPosition: 'outside',
                            lineColor: '#05fff3',
                            lineWidth: 1, // Ajusta el ancho de la línea del eje según tus necesidades
                            minorTickPosition: 'outside',
                            tickColor: '#05fff3',
                            minorTickColor: '#05fff3',
                            tickLength: 4, // Ajusta la longitud de las marcas del eje según tus necesidades
                            minorTickWidth: 1,
                            tickWidth: 1,
                            minorTickLength: 3, // Ajusta la longitud de las marcas menores del eje según tus necesidades
                            labels: {
                            distance: 6, // Ajusta la distancia de las etiquetas al eje según tus necesidades
                            rotation: 'auto',
                            style: {
                                color: '#05fff3',
                                fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                            }
                            },
                            tickPositions:
                            [
                                min,
                                min + (max-min)/4,
                                min + (max-min)/2,
                                min + 3*(max-min)/4,
                                max
                            ],
                            offset: -10,
                            endOnTick: false
                        },

                        this.Gauge.series = [{
                            name: '',
                            data: [{
                            y:  this.data.data[sensor][0],
                            }],
                            tooltip: {
                            valueSuffix: ''
                            }
                        }]

                        Highcharts.chart(idComponent[0], this.Gauge);

                        var content =
                        '<div class="content-between cursor-default text-base w-full">' +
                            '<div class="text-center flex justify-center items-center w-full whitespace-nowrap gap-1 pl-6">' +
                                '<p class="text-2xl font-sevensegment text-white-snow">' + this.data.data[sensor][0] + '</p>' +
                                '<p class="text-sm text-white-snow pb-0.5 self-end text-left w-6">' + this.data.units[sensor] + '</p>' +
                            '</div>' +
                        '</div>'

                        document.getElementById(idComponent[1]).innerHTML = content;

                    } else if (sensor == 19 || sensor == 20) { // TIEMPO

                        const time = this.getElapsedTime(this.data.data[sensor][0])

                        content =
                        '<div class="h-fit w-full grid place-items-center">' +
                            '<div class="py-2 w-full flex flex-col justify-center items-center rounded-lg border border-gray-medium gap-y-1.5 bg-darkblue-opa">' +
                                '<div class="flex flex-row justify-center items-baseline gap-2">' +
                                    '<p class="text-4xl font-sevensegment font-normal text-white-snow">' + time[0] + '</p>' +
                                    '<p class="text-md font-normal text-white-snow">' + this.$t('general.days') + '</p>' +
                                '</div>' +
                                '<div class="flex flex-row justify-center items-baseline gap-2">' +
                                    '<p class="text-2xl font-sevensegment font-normal text-white-snow">' + time[1][0] + '</p>' +
                                    '<p class="text-sm font-normal text-white-snow">' + this.$t('general.hours') + '</p>' +
                                '</div>' +
                            '</div>' +
                        '</div>';

                        document.getElementById(idComponent[0]).innerHTML = content;

                    } else if(sensor == 16 || sensor == 17 || sensor == 22 || sensor == 23 || sensor == 25 || sensor == 26){ // BLOCK

                        let max;

                        switch(parseInt(sensor)){

                            default:
                                max = 100;
                        }

                        content =
                        '<div class="h-fit w-full grid place-items-center">' +
                            '<div class="px-4 w-full flex flex-col justify-center items-center rounded-lg border border-gray-medium gap-y-0.5 text-white-snow">' +
                                '<div class="w-full flex justify-between items-center py-2 px-0.5">' +
                                    '<div class="grid place-items-center h-full">' +
                                        '<i class="' + this.getIconName((this.data.units[sensor] != null ? this.data.units[sensor] : ''), this.data.names[sensor][0]) + '" style="font-size:1.5rem; color:rgba(225, 225, 225, 0.9);"></i>' +
                                    '</div>' +
                                    '<div class="flex gap-1 whitespace-nowrap text-lg">' +
                                        '<p class="text-3xl font-sevensegment text-white-snow">' + this.data.data[sensor][0] + '</p>' +
                                        '<p class="text-sm text-white-snow self-end text-left pb-0.5">' + this.data.units[sensor] + '</p>' +
                                    '</div>' +
                                '</div>' +
                                '<div class="w-full border-gray-medium border-t pb-[1px]"></div>' +
                                '<div class="w-full flex justify-center items-center py-1">' +
                                    '<div class="flex gap-1 whitespace-nowrap text-gray-light">' +
                                        '<p class="text-lg font-sevensegment">/ ' + max + '</p>' +
                                        '<p class="text-sm pb-[3px] self-end text-left">' + this.data.units[sensor] + '</p>' +
                                    '</div>' +
                                '</div>' +
                            '</div>' +
                        '</div>';

                        document.getElementById(idComponent[0]).innerHTML = content;

                    }
                }
            }

            if(typeof this.selectedsensor != 'undefined'){
                this.updateChart(this.selectedsensor)
            }
        },

        updateChart(selectedsensor){

            if(typeof selectedsensor != 'undefined'){

                this.selectedsensor = selectedsensor;

                let chartData = new Array();
                let chartUnit = this.data.units[selectedsensor];
                let chartName = this.data.names[selectedsensor];

                this.data.epochMS.forEach( (date, index) => {
                    if(typeof this.data.data[selectedsensor][index] != 'undefined')
                        chartData.push([date, this.data.data[selectedsensor][index]])
                })

                this.Chart.yAxis = ({
                    id: 0,
                    opposite: true,
                    gridLineColor: '#647F8C',
                    title: {
                        text: ''
                    },
                    labels: {
                        formatter: function () {
                            return this.pos + ' ' + chartUnit
                        },
                        style: {
                            color: 'rgba(200, 200, 200, 0.9)',
                            opacity: 0.7,
                        }
                    },
                    visible: true,
                });

                this.Chart.tooltip.valueSuffix = chartUnit;

                this.Chart.series = [];

                this.Chart.series.push({
                    name: chartName,
                    type: 'spline',
                    yAxis: 0,
                    data: chartData.filter(point => point !== undefined && point !== null).reverse(),
                    color: "#05fff3",
                    lineWidth: 1.5,
                    zIndex: 1,
                    marker: {
                        enabled: false
                    },
                    tooltip: {
                        valueSuffix: chartUnit
                    }
                });

                Highcharts.chart('id_chart', this.Chart);

            } else {
                document.getElementById('id_chart').innerHtml = '';
            }
        },

        methodUpdateDate(modelData) {

            if( modelData[0].getFullYear() === modelData[1].getFullYear() &&
                modelData[0].getMonth() === modelData[1].getMonth() &&
                modelData[0].getDate() === modelData[1].getDate()){

                    modelData[0].setHours(0);
                    modelData[0].setMinutes(0);
                    modelData[0].setSeconds(0);

                    modelData[1].setHours(23);
                    modelData[1].setMinutes(59);
                    modelData[1].setSeconds(59);
            }

            let date_start = this.formatDate(modelData[0], 1);
            let date_end = this.formatDate(modelData[1], 1);

            axiosApiCalls.methodGet('/gateway/values/period/'+this.user.id+'/'+this.data.device.id+'/'+date_start+'/'+date_end, this.user.token)
                .then((response) => {

                    if(response.dates.length == 0){
                        window.emitter.emit(
                            'AppLayout_alert',
                            true,
                            this.$t('general.Gateway without records'),
                            this.$t('text.lacks records period'),
                            '18rem'
                        )
                    }

                    this.data.data = response.data;
                    this.data.dates = response.dates;
                    this.data.epochMS = response.epochMS;
                    this.data.data[36] = new Array(this.data.dates.length).fill(0);

                    this.rechargePage();
                    //return response;
                })
        },

        methodFormatDatetoDatepicker() {
            return generateDateDatepicker(this.date)
        },

        generateDateDatepicker(date) {

            var day1 = date[0].getDate();
            var month1 = date[0].getMonth() + 1;
            var year1 = date[0].getFullYear();
            var hour1 = date[0].getHours();
            var min1 = date[0].getMinutes();

            if(month1.toString().length == 1) month1 = '0' + month1;
            if(day1.toString().length == 1) day1 = '0' + day1;
            if(hour1.toString().length == 1) hour1 = '0' + hour1;
            if(min1.toString().length == 1) min1 = '0' + min1;

            var day2 = date[1].getDate();
            var month2 = date[1].getMonth() + 1;
            var year2 = date[1].getFullYear();
            var hour2 = date[1].getHours();
            var min2 = date[1].getMinutes();

            if(month2.toString().length == 1) month2 = '0' + month2;
            if(day2.toString().length == 1) day2 = '0' + day2;
            if(hour2.toString().length == 1) hour2 = '0' + hour2;
            if(min2.toString().length == 1) min2 = '0' + min2;

            return `${year1}/${month1}/${day1} ${hour1}:${min1} `+ this.$t("general.To") +` ${year2}/${month2}/${day2} ${hour2}:${min2}`;
        },

        mqtt_connection(iddevice) {

            var mqtt_topic = "/PUSHER/@P@" + this.user.idplatform + "/G@" + this.user.idgroup_selected + "/@D@" + iddevice;

            const mqtt = require('paho-mqtt');

            const mqtt_host = 'mqtt.datakorum.app';
            const mqtt_port = 8000;
            const mqtt_path = '';

            var userName = this.user.credentials.username;
            var password = this.user.credentials.password;

            var clientId = "APPclientid_" + parseInt(Math.random() * 100, 10);

            const client = new mqtt.Client(mqtt_host, mqtt_port, mqtt_path, clientId);

            client.connect({

            useSSL: true,
            mqttVersion: 4,
            userName: userName,
            password: password,

            onSuccess: () => {
                // función de éxito de conexión

                client.subscribe(mqtt_topic, {

                onSuccess: () => {
                    console.log('éxito de suscripción ' + iddevice)
                    // función de éxito de suscripción
                },

                onFailure: () => {
                    // función de fallo de suscripción
                    console.error('fallo de suscripción ' + iddevice)
                }

                });
            },

            onFailure: () => {
                // función de fallo de conexión
                console.error('fallo de conexión ' + iddevice)
            }

            });

            client.onConnectionLost = () => {
                // función que se ejecuta cuando perdemos la conexión
                console.error('perdida de conexión ' + iddevice)

                setTimeout(() => {
                    this.mqtt_connection(iddevice)
                }, 5000);

            };

            client.onMessageArrived = (message) => {
                // función que se ejecuta cuando llega un mensaje al topic suscrito

                var data = JSON.parse(JSON.parse(message.payloadString).frame_data);
                var when = this.formatDate(JSON.parse(message.payloadString).when * 1000);

                this.rechargePage();

            };
        },

        openParameters(){
            this.parametersModal = true
        },

        updateParameters(){
            if(this.timeout_command == undefined){
                this.SetTimerCommand()
            } else {
                window.alert(this.$t('text.Watch out!'));
                //console.error(this.$t('text.Watch out!'))
                //this.showNotification(this.$t('general.Hasty attempt'), this.$t('text.Watch out!'), 7);
            }
        },

        SetTimerCommand(){
            const sendDelay = 30;
            this.timeout_command = 1;

            document.getElementById('idUpdate_1').innerHTML = sendDelay - this.timeout_command;
            document.getElementById('idUpdate_2').innerHTML = sendDelay - this.timeout_command;

            const intervalId = setInterval(() => {
                if (this.timeout_command < sendDelay) {
                    this.timeout_command++;

                        document.getElementById('idUpdate_1').innerHTML = sendDelay - this.timeout_command;
                        document.getElementById('idUpdate_2').innerHTML = sendDelay - this.timeout_command;

                } else {
                    clearInterval(intervalId);

                        document.getElementById('idUpdate_1').innerHTML = this.$t('general.Update');
                        document.getElementById('idUpdate_2').innerHTML = this.$t('general.Update');

                    this.timeout_command = undefined;
                }
            }, 1000);
        },

        closeParameters(){
            this.parametersModal = false
        },

        showNotification(title, message, time){

            if(time == undefined){
                time = 7500;
            }else{
                time = time * 1000
            }

            this.Show_Notification = true;
            this.Notification_Title = title;
            this.Notification_Message = message;

            setTimeout(() => {
                this.Show_Notification = false;
                this.Notification_Title = "";
                this.Notification_Message = "";
            }, time);

        },

        getIconName(unit, input){

            let icon;

            switch(unit){
                case 'W': icon = 'DK-voltaje'; break;
                case 'kWh': icon = 'DK-voltaje'; break;
                case '': icon = 'DK-analogico'; break;
            }

            if(icon == undefined){
                input = input.toString()
                icon = 'fa-solid fa-' + input.toLowerCase();
            }

            return icon;
        },

        getBoolBit(value, bit) {
            //value = 2047 // quitar "|| true" y "value = 2047"
            return value.toString(2)[bit] == '1';
        },

        setSensor(sensor){

            if(this.selectedSensor != sensor){
                this.selectedSensor = sensor;

                setTimeout(() => {
                    this.updateChart(sensor)
                }, 0);
            } else {
                this.selectedSensor = undefined;

                setTimeout(() => {
                    this.updateChart(undefined)
                }, 0);
            }
        },
    },
}
</script>
